==> sdk-1.0.38-sources.jar: main/nashid/verify/sdk/ui/InstructionScreen.kt <==
package nashid.verify.sdk.ui

import android.app.Activity
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.WindowInsets
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.systemBars
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.windowInsetsPadding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.SideEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import nashid.verify.sdk.ui.theme.FontManager
import nashid.verify.sdk.utils.Screens
import nashid.verify.sdk.utils.SdkConfig
import nashid.verify.sdk.utils.helpers.EdgeToEdgeHelper
import nashid.verify.sdkNew.R

@Composable
fun InstructionPreview(
    steps: List<Step>,
    navController: NavController,
    onBackClick: () -> Unit,
) {
    val context = LocalContext.current
    val activity = context as? Activity ?: return

    // Handle edge-to-edge mode and status bar using EdgeToEdgeHelper
    SideEffect {
        val statusBarColor = SdkConfig.sdkAppTheme.getBackgroundColorInt()
        EdgeToEdgeHelper.setupEdgeToEdgeWithStatusBar(activity, statusBarColor)
    }
    Box(
        modifier =
            Modifier
                .fillMaxSize()
                .background(SdkConfig.sdkAppTheme.getBackgroundColor())
                .windowInsetsPadding(WindowInsets.systemBars),
    ) {
        Column(
            modifier =
                Modifier
                    .fillMaxSize(),
        ) {
            Row(
                modifier =
                    Modifier
                        .fillMaxWidth()
                        .padding(top = 10.dp, end = 25.dp, start = 5.dp),
                verticalAlignment = Alignment.CenterVertically,
            ) {
                IconButton(onClick = onBackClick) {
                    Icon(
                        painter = painterResource(R.drawable.back),
                        contentDescription = "Back Arrow",
                        tint = SdkConfig.sdkAppTheme.getPrimaryColor(),
                    )
                }
                Text(
                    text = stringResource(R.string.verification_steps),
                    fontFamily = FontManager.getFontFamily(),
                    fontWeight = FontWeight.Medium,
                    color = SdkConfig.sdkAppTheme.getHeaderColor(),
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center,
                    modifier = Modifier.weight(4f),
                )
            }

            Spacer(modifier = Modifier.height(8.dp))
            LazyColumn(
                modifier =
                    Modifier
                        .weight(1f)
                        .padding(20.dp),
            ) {
                items(steps) { step ->
                    StepListItem(step)
                }
            }
            NextButton {
                navController.navigate(Screens.StartScanning.route) {
                    popUpTo(Screens.InstructionScreen.route) { inclusive = true }
                }
            }
        }
    }
}

@Composable
fun StepListItem(step: Step) {
    Row(
        modifier =
            Modifier
                .fillMaxWidth()
                .padding(vertical = 8.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        Card(
            modifier =
                Modifier
                    .size(85.dp)
                    .padding(top = 8.dp),
            colors = CardDefaults.cardColors(colorResource(id = R.color.step_bg_color)),
            shape = RoundedCornerShape(6.dp),
        ) {
            Image(
                painter = painterResource(step.imageRes),
                contentDescription = "Step icon",
                modifier = Modifier.fillMaxSize(),
                contentScale = ContentScale.Inside,
            )
        }

        Spacer(modifier = Modifier.width(8.dp))

        Column(
            verticalArrangement = Arrangement.Center,
            modifier =
                Modifier
                    .fillMaxWidth()
                    .padding(start = 8.dp),
        ) {
            Text(
                text = step.title,
                fontFamily = FontManager.getFontFamily(),
                fontWeight = FontWeight.Medium,
                color = colorResource(id = R.color.step_header),
            )
            Text(
                text = step.description,
                fontFamily = FontManager.getFontFamily(),
                fontWeight = FontWeight.Medium,
                color = SdkConfig.sdkAppTheme.getHeaderColor(),
            )
        }
    }
}

@Composable
fun NextButton(onNextClick: () -> Unit) {
    Card(
        shape = RoundedCornerShape(6.dp),
        onClick = onNextClick,
        colors = CardDefaults.cardColors(SdkConfig.sdkAppTheme.getPrimaryColor()),
        modifier =
            Modifier
                .fillMaxWidth()
                .padding(16.dp),
    ) {
        Text(
            text = stringResource(id = R.string.next),
            fontFamily = FontManager.getFontFamily(),
            fontWeight = FontWeight.Medium,
            color = SdkConfig.sdkAppTheme.getBackgroundColor(),
            modifier =
                Modifier
                    .padding(vertical = 16.dp)
                    .fillMaxWidth(),
            fontSize = 16.sp,
            textAlign = TextAlign.Center,
        )
    }
}

data class Step(val title: String, val description: String, val imageRes: Int)

@Composable
fun InstructionScreen(navController: NavController) {
    val context = LocalContext.current
    val steps =
        listOf(
            Step(stringResource(id = R.string.scan), stringResource(id = R.string.scan_desc), R.drawable.step1),
            Step(stringResource(id = R.string.tap), stringResource(id = R.string.tap_desc), R.drawable.step2),
            Step(stringResource(id = R.string.smile), stringResource(id = R.string.smile_desc), R.drawable.step3),
        )
    InstructionPreview(steps, navController) {
        (context as? Activity)?.finish()
    }
}

@Preview(showBackground = true)
@Composable
fun InstructionScreen() {
    InstructionPreview(
        steps =
            listOf(
                Step(stringResource(id = R.string.scan), stringResource(id = R.string.scan_desc), R.drawable.step1),
                Step(stringResource(id = R.string.tap), stringResource(id = R.string.tap_desc), R.drawable.step2),
                Step(stringResource(id = R.string.smile), stringResource(id = R.string.smile_desc), R.drawable.step3),
            ),
        navController = rememberNavController(),
        onBackClick = {},
    )
}

==> sdk-2.6.0-sources.jar: main/nashid/verify/sdk/ui/InstructionScreen.kt <==
package nashid.verify.sdk.ui

import android.app.Activity
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.WindowInsets
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.systemBars
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.windowInsetsPadding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.SideEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import nashid.verify.sdk.ui.theme.FontManager
import nashid.verify.sdk.utils.Screens
import nashid.verify.sdk.utils.SdkConfig
import nashid.verify.sdk.utils.helpers.EdgeToEdgeHelper
import nashid.verify.sdkNew.R

@Composable
fun InstructionPreview(
    steps: List<Step>,
    navController: NavController,
    onBackClick: () -> Unit,
) {
    val context = LocalContext.current
    val activity = context as? Activity ?: return

    // Handle edge-to-edge mode and status bar using EdgeToEdgeHelper
    SideEffect {
        val statusBarColor = SdkConfig.sdkAppTheme.getBackgroundColorInt()
        EdgeToEdgeHelper.setupEdgeToEdgeWithStatusBar(activity, statusBarColor)
    }
    Box(
        modifier =
            Modifier
                .fillMaxSize()
                .background(SdkConfig.sdkAppTheme.getBackgroundColor())
                .windowInsetsPadding(WindowInsets.systemBars),
    ) {
        Column(
            modifier =
                Modifier
                    .fillMaxSize(),
        ) {
            Row(
                modifier =
                    Modifier
                        .fillMaxWidth()
                        .padding(top = 10.dp, end = 25.dp, start = 5.dp),
                verticalAlignment = Alignment.CenterVertically,
            ) {
                IconButton(onClick = onBackClick) {
                    Icon(
                        painter = painterResource(R.drawable.back),
                        contentDescription = "Back Arrow",
                        tint = SdkConfig.sdkAppTheme.getPrimaryColor(),
                    )
                }
                Text(
                    text = stringResource(R.string.verification_steps),
                    fontFamily = FontManager.getFontFamily(),
                    fontWeight = FontWeight.Medium,
                    color = SdkConfig.sdkAppTheme.getHeaderColor(),
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center,
                    modifier = Modifier.weight(4f),
                )
            }

            Spacer(modifier = Modifier.height(8.dp))
            LazyColumn(
                modifier =
                    Modifier
                        .weight(1f)
                        .padding(20.dp),
            ) {
                items(steps) { step ->
                    StepListItem(step)
                }
            }
            NextButton {
                navController.navigate(Screens.StartScanning.route) {
                    popUpTo(Screens.InstructionScreen.route) { inclusive = true }
                }
            }
        }
    }
}

@Composable
fun StepListItem(step: Step) {
    Row(
        modifier =
            Modifier
                .fillMaxWidth()
                .padding(vertical = 8.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        Card(
            modifier =
                Modifier
                    .size(85.dp)
                    .padding(top = 8.dp),
            colors = CardDefaults.cardColors(colorResource(id = R.color.step_bg_color)),
            shape = RoundedCornerShape(6.dp),
        ) {
            Image(
                painter = painterResource(step.imageRes),
                contentDescription = "Step icon",
                modifier = Modifier.fillMaxSize(),
                contentScale = ContentScale.Inside,
            )
        }

        Spacer(modifier = Modifier.width(8.dp))

        Column(
            verticalArrangement = Arrangement.Center,
            modifier =
                Modifier
                    .fillMaxWidth()
                    .padding(start = 8.dp),
        ) {
            Text(
                text = step.title,
                fontFamily = FontManager.getFontFamily(),
                fontWeight = FontWeight.Medium,
                color = colorResource(id = R.color.step_header),
            )
            Text(
                text = step.description,
                fontFamily = FontManager.getFontFamily(),
                fontWeight = FontWeight.Medium,
                color = SdkConfig.sdkAppTheme.getHeaderColor(),
            )
        }
    }
}

@Composable
fun NextButton(onNextClick: () -> Unit) {
    Card(
        shape = RoundedCornerShape(6.dp),
        onClick = onNextClick,
        colors = CardDefaults.cardColors(SdkConfig.sdkAppTheme.getPrimaryColor()),
        modifier =
            Modifier
                .fillMaxWidth()
                .padding(16.dp),
    ) {
        Text(
            text = stringResource(id = R.string.next),
            fontFamily = FontManager.getFontFamily(),
            fontWeight = FontWeight.Medium,
            color = SdkConfig.sdkAppTheme.getBackgroundColor(),
            modifier =
                Modifier
                    .padding(vertical = 16.dp)
                    .fillMaxWidth(),
            fontSize = 16.sp,
            textAlign = TextAlign.Center,
        )
    }
}

data class Step(val title: String, val description: String, val imageRes: Int)

@Composable
fun InstructionScreen(navController: NavController) {
    val context = LocalContext.current
    val steps = getSteps()
    InstructionPreview(steps, navController) {
        (context as? Activity)?.finish()
    }
}

@Preview(showBackground = true)
@Composable
fun InstructionScreen() {
    val steps = getSteps()
    InstructionPreview(
        steps = steps,
        navController = rememberNavController(),
        onBackClick = {},
    )
}

@Composable
fun getSteps(): List<Step> {
    // Ensure stringResource is only called inside @Composable
    return buildList {
        add(
            Step(
                stringResource(id = R.string.scan),
                stringResource(id = R.string.scan_desc),
                R.drawable.step1,
            ),
        )

        if (SdkConfig.isNfcScanningEnabled) {
            add(
                Step(
                    stringResource(id = R.string.tap),
                    stringResource(id = R.string.tap_desc),
                    R.drawable.step2,
                ),
            )
        }

        if (SdkConfig.isActiveLiveNessEnabled || SdkConfig.isPassiveLiveNessEnabled) {
            add(
                Step(
                    stringResource(id = R.string.smile),
                    stringResource(id = R.string.smile_desc),
                    R.drawable.step3,
                ),
            )
        }
    }
}
